@@ -20,11 +20,7 @@ from .Config import Config
 
 class Latte(object):
 
-    """
-
-    Main application class
-
-    """
+    """ Main application class. """
 
     def __init__(self):
         self.configs = Config()
@@ -34,51 +30,37 @@ class Latte(object):
                                    categorizer=self.categorizer,
                                    projectizer=self.projectizer)
 
-        # Register a cleanup
         atexit.register(self.cleanup)
 
-        # Add application configuration path
-        if not os.path.exists(self.configs.get('app_path')):
-            os.makedirs(self.configs.get('app_path'))
-
     def cleanup(self):
-        """
-
-        Atexit cleanup method. Force dumps log information to the filesystem
-
-        """
+        """ On exit force dump log information. """
         self.tracker.dump_logs()
 
     def run(self):
-        """
-
-        Primary application loop
-
-        """
+        """ Primary application loop. """
         duration = 0
-        while True:
-            title = get_active_window_title()
-            if title:
-                self.tracker.log(title)
-                stats = self.tracker.get_window_stats(title)
-                print title, \
-                    repr(stats['categories']), \
-                    repr(stats['project']), \
-                    stats['time']
+        try:
+            while True:
+                title = get_active_window_title()
+                if title:
+                    self.tracker.log(title)
+                    stats = self.tracker.get_window_stats(title)
+                    print title, \
+                        repr(stats['categories']), \
+                        repr(stats['project']), \
+                        stats['time']
 
-            time.sleep(self.configs.getint('sleep_time'))
-            # Track time since last save and do autosaves
-            duration += self.configs.getint('sleep_time')
-            if duration >= self.configs.getint('autosave_time'):
-                duration = 0
-                self.tracker.dump_logs()
+                time.sleep(self.configs.get('sleep_time'))
+                # Track time since last save and do autosaves
+                duration += self.configs.get('sleep_time')
+                if duration >= self.configs.get('autosave_time'):
+                    duration = 0
+                    self.tracker.dump_logs()
+        except KeyboardInterrupt:
+            print 'Exiting...'
 
 def get_active_window_title():
-    """
-
-    Fetches active window title using xprop
-
-    """
+    """ Fetches active window title using xprop. """
     try:
         active = subprocess.Popen(["xprop", "-root", "_NET_ACTIVE_WINDOW"],
                                 stdout=subprocess.PIPE)
